package zone

import (
	"context"
	"encoding/json"
	"net/http"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// ListRequest struct to get list of zones
type ListRequest struct {

	// Find by ID
	// Required: false
	ByID uint64 `url:"by_id,omitempty" json:"by_id,omitempty"`

	// Find by Grid ID
	// Required: false
	GID uint64 `url:"gid,omitempty" json:"gid,omitempty"`

	// Find by name
	// Required: false
	Name string `url:"name,omitempty" json:"name,omitempty"`

	// Find by description
	// Required: false
	Description string `url:"description,omitempty" json:"description,omitempty"`

	// Find by status
	// Required: false
	Status string `url:"status,omitempty" json:"status,omitempty"`

	// Find by deletable
	// Required: false
	Deletable bool `url:"deletable,omitempty" json:"deletable,omitempty"`

	// Find by node ID
	// Required: false
	NodeID uint64 `url:"nodeId,omitempty" json:"nodeId,omitempty"`

	// Sort by one of supported fields, format +|-(field)
	// Required: false
	SortBy string `url:"sortBy,omitempty" json:"sortBy,omitempty" validate:"omitempty,sortBy"`

	// Page number
	// Required: false
	Page uint64 `url:"page,omitempty" json:"page,omitempty"`

	// Page size
	// Required: false
	Size uint64 `url:"size,omitempty" json:"size,omitempty"`
}

// List gets list of all zones as a ListZones struct
func (e Zone) List(ctx context.Context, req ListRequest) (*ListZones, error) {

	res, err := e.ListRaw(ctx, req)
	if err != nil {
		return nil, err
	}

	list := ListZones{}

	err = json.Unmarshal(res, &list)
	if err != nil {
		return nil, err
	}

	return &list, nil
}

// ListRaw gets list of all available zones as an array of bytes
func (e Zone) ListRaw(ctx context.Context, req ListRequest) ([]byte, error) {

	if err := validators.ValidateRequest(req); err != nil {
		return nil, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudapi/zone/list"

	res, err := e.client.DecortApiCall(ctx, http.MethodPost, url, req)
	return res, err
}
