package lb

import (
	"context"
	"net/http"
	"strconv"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// MigrateToZone struct to move lb to another zone
type MigrateToZoneRequest struct {
	// ID of the load balancer instance to move
	// Required: true
	LBID uint64 `url:"lbId" json:"lbId" validate:"required"`

	// ID of the zone to move
	// Required: true
	ZoneID uint64 `url:"zoneId" json:"zoneId" validate:"required"`
}

// MigrateToZone moves lb instance to new zone
func (l LB) MigrateToZone(ctx context.Context, req MigrateToZoneRequest) (bool, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return false, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/lb/migrateToZone"

	res, err := l.client.DecortApiCall(ctx, http.MethodPost, url, req)
	if err != nil {
		return false, err
	}

	result, err := strconv.ParseBool(string(res))
	if err != nil {
		return false, err
	}

	return result, nil
}
