package user

import (
	"context"
	"net/http"
	"strconv"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// UnblockRequest struct to block a user.
type UnblockRequest struct {
	// ID of the user to block.
	// Required: true
	UserID string `url:"user_id" json:"user_id" validate:"required"`
}

// Unblock unblocks a user
func (u User) Unblock(ctx context.Context, req UnblockRequest) (bool, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return false, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/user/unblock"

	res, err := u.client.DecortApiCall(ctx, http.MethodPost, url, req)
	if err != nil {
		return false, err
	}

	result, err := strconv.ParseBool(string(res))
	if err != nil {
		return false, err
	}

	return result, nil
}
