package zone

import (
	"context"
	"net/http"
	"strconv"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// DeleteRequest struct to delete zone
type DeleteRequest struct {
	// ID of zone
	// Required: true
	ID uint64 `url:"id" json:"id" validate:"required"`
}

// Delete deletes zone object
func (e Zone) Delete(ctx context.Context, req DeleteRequest) (bool, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return false, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/zone/delete"

	res, err := e.client.DecortApiCall(ctx, http.MethodPost, url, req)

	if err != nil {
		return false, err
	}

	result, err := strconv.ParseBool(string(res))
	if err != nil {
		return false, err
	}

	return result, nil
}
