package zone

import (
	"context"
	"net/http"
	"strconv"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// UpdateRequest struct to update zone
type UpdateRequest struct {
	// ID of zone
	// Required: true
	ID uint64 `url:"id" json:"id" validate:"required"`

	// Name of zone
	// Required: false
	Name string `url:"name,omitempty" json:"name,omitempty"`

	// Description
	// Required: false
	Description string `url:"description,omitempty" json:"description,omitempty"`
}

// Update updates zone object
func (e Zone) Update(ctx context.Context, req UpdateRequest) (bool, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return false, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/zone/update"

	res, err := e.client.DecortApiCall(ctx, http.MethodPost, url, req)

	if err != nil {
		return false, err
	}

	result, err := strconv.ParseBool(string(res))
	if err != nil {
		return false, err
	}

	return result, nil
}
